==> openGion_dev_5.1.1.0.zip: opengion/uap/webapps/ge/db/mysql/sql/01_TABLE/GE53S.sql <==
/**************************************************************************/
/* GE53 ( 振分条件マスタ )                                                */
/*                                                                        */
/* Created : 2009/11/17 09:27:38                                          */
/**************************************************************************/
CREATE TABLE GE53 (
   SYSTEM_ID     VARCHAR(10)                      NOT NULL      /* 10  システムID       */
 , JOKEN         VARCHAR(20)                      NOT NULL      /* 20  振分条件         */
 , FGRUN         VARCHAR(1)                       NOT NULL      /* 30  実行方法         */
 , PRTID         VARCHAR(20)                                    /* 40  プリンタID       */
 , LANG          VARCHAR(2)                                     /* 50  言語             */
 , PRGDIR        VARCHAR(100)                     NOT NULL      /* 60  実行PGDIR        */
 , PRGFILE       VARCHAR(50)                      NOT NULL      /* 70  実行PGファイル名 */
 , COMMENTS      VARCHAR(500)                                   /* 80  コメント         */
 , DMN_GRP       VARCHAR(20)     DEFAULT 'DG0000' NOT NULL      /* 150 デーモングループ */
 , DMN_TIME      INTEGER         DEFAULT 5        NOT NULL      /* 160 デーモン間隔     */
 , RELEASE_NOTES VARCHAR(120)                                   /* 170 リリースノート   */
 , RDC_CODE      VARCHAR(20)                                    /* 180 設変番号         */
 , OUT_DIR       VARCHAR(100)                                   /* 190 出力ファイルDIR  */
 , OUT_FILE      VARCHAR(50)                                    /* 200 出力ファイル名   */
 , JKN_GRP       VARCHAR(20)                                    /* 210 条件グループ     */
 , FGJ           VARCHAR(1)      DEFAULT '1'      NOT NULL      /* 810 状態フラグ       */
 , DYSET         VARCHAR(14)                                    /* 820 登録日時         */
 , PGSET         VARCHAR(10)                                    /* 830 作成PG           */
 , PGPSET        VARCHAR(10)                                    /* 840 作成親PG         */
 , USRSET        VARCHAR(10)                                    /* 850 作成社員         */
 , DYUPD         VARCHAR(14)                                    /* 860 更新日時         */
 , PGUPD         VARCHAR(10)                                    /* 870 更新PG           */
 , PGPUPD        VARCHAR(10)                                    /* 880 更新親PG         */
 , USRUPD        VARCHAR(10)                                    /* 890 更新者           */
);

==> openGion_dev_5.1.1.2.zip: opengion/uap/webapps/ge/db/mysql/sql/01_TABLE/GE53S.sql <==
/**************************************************************************/
/* GE53 ( 振分条件マスタ )                                                */
/*                                                                        */
/* Created : 2009/12/10 12:29:59                                          */
/**************************************************************************/
CREATE TABLE GE53 (
   SYSTEM_ID     VARCHAR(10)                      NOT NULL      /* 10  システムID       */
 , JOKEN         VARCHAR(20)                      NOT NULL      /* 20  振分条件         */
 , FGRUN         VARCHAR(1)                       NOT NULL      /* 30  実行方法         */
 , PRTID         VARCHAR(20)                                    /* 40  プリンタID       */
 , LANG          VARCHAR(2)                                     /* 50  言語             */
 , PRGDIR        VARCHAR(100)                     NOT NULL      /* 60  実行PGDIR        */
 , PRGFILE       VARCHAR(50)                      NOT NULL      /* 70  実行PGファイル名 */
 , COMMENTS      TEXT                                           /* 80  コメント         */
 , DMN_GRP       VARCHAR(20)     DEFAULT 'DG0000' NOT NULL      /* 150 デーモングループ */
 , DMN_TIME      INTEGER         DEFAULT 5        NOT NULL      /* 160 デーモン間隔     */
 , RELEASE_NOTES VARCHAR(120)                                   /* 170 リリースノート   */
 , RDC_CODE      VARCHAR(20)                                    /* 180 設変番号         */
 , OUT_DIR       VARCHAR(100)                                   /* 190 出力ファイルDIR  */
 , OUT_FILE      VARCHAR(50)                                    /* 200 出力ファイル名   */
 , JKN_GRP       VARCHAR(20)                                    /* 210 条件グループ     */
 , FGJ           VARCHAR(1)      DEFAULT '1'      NOT NULL      /* 810 状態フラグ       */
 , DYSET         VARCHAR(14)                                    /* 820 登録日時         */
 , PGSET         VARCHAR(10)                                    /* 830 作成PG           */
 , PGPSET        VARCHAR(10)                                    /* 840 作成親PG         */
 , USRSET        VARCHAR(10)                                    /* 850 作成社員         */
 , DYUPD         VARCHAR(14)                                    /* 860 更新日時         */
 , PGUPD         VARCHAR(10)                                    /* 870 更新PG           */
 , PGPUPD        VARCHAR(10)                                    /* 880 更新親PG         */
 , USRUPD        VARCHAR(10)                                    /* 890 更新者           */
);
